@@ -364,6 +364,21 @@ int vips_vipssave( VipsImage *in, const char *filename, ... )
 int vips_openslideload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+/**
+ * VipsForeignJpegSubsample:
+ * @VIPS_FOREIGN_JPEG_SUBSAMPLE_AUTO: default preset
+ * @VIPS_FOREIGN_JPEG_SUBSAMPLE_ON: always perform subsampling
+ * @VIPS_FOREIGN_JPEG_SUBSAMPLE_OFF: never perform subsampling
+ *
+ * Set jpeg subsampling mode.
+ */
+typedef enum {
+	VIPS_FOREIGN_JPEG_SUBSAMPLE_AUTO,
+	VIPS_FOREIGN_JPEG_SUBSAMPLE_ON,
+	VIPS_FOREIGN_JPEG_SUBSAMPLE_OFF,
+	VIPS_FOREIGN_JPEG_SUBSAMPLE_LAST
+} VipsForeignJpegSubsample;
+
 int vips_jpegload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_jpegload_buffer( void *buf, size_t len, VipsImage **out, ... )
@@ -430,7 +445,7 @@ int vips_webpsave_mime( VipsImage *in, ... )
  *
  * Use @Q to set the jpeg compression level, default 75.
  *
- * Use @prediction to set the lzw or deflate prediction, default none.
+ * Use @predictor to set the lzw or deflate prediction, default horizontal.
  *
  * Use @lossless to set WEBP lossless compression.
  *
@@ -449,7 +464,7 @@ typedef enum {
 } VipsForeignTiffCompression;
 
 /**
- * VipsForeignTiffPredictor:
+ * VipsForeignTiffPoor:
  * @VIPS_FOREIGN_TIFF_PREDICTOR_NONE: no prediction
  * @VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL: horizontal differencing
  * @VIPS_FOREIGN_TIFF_PREDICTOR_FLOAT: float predictor
@@ -509,13 +524,21 @@ int vips_rawsave_fd( VipsImage *in, int fd, ... )
 
 int vips_csvload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_csvload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 int vips_csvsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+int vips_csvsave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
 
 int vips_matrixload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_matrixload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 int vips_matrixsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+int vips_matrixsave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
 int vips_matrixprint( VipsImage *in, ... )
 	__attribute__((sentinel));
 
@@ -564,8 +587,12 @@ int vips_pngsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 
 int vips_ppmload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_ppmload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 int vips_ppmsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+int vips_ppmsave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
 
 int vips_matload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
@@ -587,6 +614,8 @@ int vips_pdfload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_pdfload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_pdfload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 
 int vips_svgload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
@@ -597,15 +626,21 @@ int vips_gifload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_gifload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_gifload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 
 int vips_heifload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_heifload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_heifload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 int vips_heifsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
 int vips_heifsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+int vips_heifsave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
 
 int vips_niftiload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
